@@ -4,7 +4,7 @@ from django.utils.module_loading import import_string
 
 DJANGO_LOCI_GEOCODER = getattr(settings, 'DJANGO_LOCI_GEOCODER', 'ArcGIS')
 DJANGO_LOCI_GEOCODE_STRICT_TEST = getattr(
-    settings, 'DJANGO_LOCI_STRICT_GEOCODE_TEST', True
+    settings, 'DJANGO_LOCI_GEOCODE_STRICT_TEST', True
 )
 DJANGO_LOCI_GEOCODE_FAILURE_DELAY = getattr(
     settings, 'DJANGO_LOCI_GEOCODE_FAILURE_DELAY', 1
