@@ -100,3 +100,66 @@ class BaseTestAdmin(TestAdminMixin, TestLociMixin):
             'geometry': {'type': 'Point', 'coordinates': [12.512124, 41.898903]},
         }
         self.assertEqual(content1, expected)
+
+    def test_geocode(self):
+        self._login_as_admin()
+        address = 'Red Square'
+        url = '{0}?address={1}'.format(
+            reverse('admin:django_loci_location_geocode_api'), address
+        )
+        response = self.client.get(url)
+        response_lat = round(response.json()['lat'])
+        response_lng = round(response.json()['lng'])
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response_lat, 56)
+        self.assertEqual(response_lng, 38)
+
+    def test_geocode_no_address(self):
+        self._login_as_admin()
+        url = reverse('admin:django_loci_location_geocode_api')
+        response = self.client.get(url)
+        expected = {'error': 'Address parameter not defined'}
+        self.assertEqual(response.status_code, 400)
+        self.assertEqual(response.json(), expected)
+
+    def test_geocode_invalid_address(self):
+        self._login_as_admin()
+        invalid_address = 'thisaddressisnotvalid123abc'
+        url = '{0}?address={1}'.format(
+            reverse('admin:django_loci_location_geocode_api'), invalid_address
+        )
+        response = self.client.get(url)
+        expected = {'error': 'Not found location with given name'}
+        self.assertEqual(response.status_code, 404)
+        self.assertEqual(response.json(), expected)
+
+    def test_reverse_geocode(self):
+        self._login_as_admin()
+        lat = 52
+        lng = 21
+        url = '{0}?lat={1}&lng={2}'.format(
+            reverse('admin:django_loci_location_reverse_geocode_api'), lat, lng
+        )
+        response = self.client.get(url)
+        self.assertEqual(response.status_code, 200)
+        self.assertContains(response, 'POL')
+
+    def test_reverse_location_with_no_address(self):
+        self._login_as_admin()
+        lat = -30
+        lng = -30
+        url = '{0}?lat={1}&lng={2}'.format(
+            reverse('admin:django_loci_location_reverse_geocode_api'), lat, lng
+        )
+        response = self.client.get(url)
+        response_address = response.json()['address']
+        self.assertEqual(response.status_code, 404)
+        self.assertEqual(response_address, '')
+
+    def test_reverse_geocode_no_coords(self):
+        self._login_as_admin()
+        url = reverse('admin:django_loci_location_reverse_geocode_api')
+        response = self.client.get(url)
+        expected = {'error': 'lat or lng parameter not defined'}
+        self.assertEqual(response.status_code, 400)
+        self.assertEqual(response.json(), expected)
