@@ -5,7 +5,7 @@ from openwisp_utils.base import TimeStampedEditableModel
 
 
 class Device(TimeStampedEditableModel):
-    name = models.CharField(_('name'), max_length=75)
+    name = models.CharField(_("name"), max_length=75)
 
     def __str__(self):
         return self.name
